@@ -3,13 +3,9 @@ import re
 from collections import defaultdict
 from hashlib import md5
 
-from hrepr import HTML
-
 from .researchers import Researchers
 from .utils import T, asciiify, download, join, normalize as _norm, print_field
 
-H = HTML()
-
 
 class Papers:
     """Collection of papers."""
@@ -87,7 +83,9 @@ class Papers:
 
     def sorted(self, field="date", desc=False):
         results = list(
-            sorted(self.papers.values(), key=lambda paper: getattr(paper, field))
+            sorted(
+                self.papers.values(), key=lambda paper: getattr(paper, field)
+            )
         )
         if desc:
             results.reverse()
